@@ -82,7 +82,10 @@ def snapshot_get_latest(
 
     """
     visit_status = origin_get_latest_visit_status(
-        storage, origin, allowed_statuses=allowed_statuses, require_snapshot=True,
+        storage,
+        origin,
+        allowed_statuses=allowed_statuses,
+        require_snapshot=True,
     )
     if not visit_status:
         return None
