@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021  The Software Heritage developers
+# Copyright (C) 2015-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -7,6 +7,7 @@ import datetime
 from enum import Enum
 from typing import Any, Dict, Iterable, List, Optional, Sequence, Tuple, TypeVar
 
+import attr
 from typing_extensions import Protocol, TypedDict, runtime_checkable
 
 from swh.core.api import remote_api_endpoint
@@ -54,6 +55,12 @@ class PartialBranches(TypedDict):
     the snapshot has less than the request number of branches."""
 
 
+@attr.s
+class OriginVisitWithStatuses:
+    visit = attr.ib(type=OriginVisit)
+    statuses = attr.ib(type=List[OriginVisitStatus])
+
+
 TResult = TypeVar("TResult")
 PagedResult = CorePagedResult[TResult, str]
 
@@ -456,6 +463,19 @@ class StorageInterface(Protocol):
         """
         ...
 
+    @remote_api_endpoint("directory/get_raw_manifest")
+    def directory_get_raw_manifest(
+        self, directory_ids: List[Sha1Git]
+    ) -> Dict[Sha1Git, Optional[bytes]]:
+        """Returns the raw manifest of directories that do not fit the SWH data model,
+        or None if they do.
+        Directories missing from the archive are not returned at all.
+
+        Args:
+            directory_ids: List of directory ids to query
+        """
+        ...
+
     @remote_api_endpoint("directory/get_random")
     def directory_get_random(self) -> Sha1Git:
         """Finds a random directory id.
@@ -519,11 +539,15 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("revision")
-    def revision_get(self, revision_ids: List[Sha1Git]) -> List[Optional[Revision]]:
+    def revision_get(
+        self, revision_ids: List[Sha1Git], ignore_displayname: bool = False
+    ) -> List[Optional[Revision]]:
         """Get revisions from storage
 
         Args:
             revisions: revision ids
+            ignore_displayname: return the original author/committer's full name even if
+              it's masked by a displayname.
 
         Returns:
             list of revision object (if the revision exists or None otherwise)
@@ -591,12 +615,17 @@ class StorageInterface(Protocol):
 
     @remote_api_endpoint("revision/log")
     def revision_log(
-        self, revisions: List[Sha1Git], limit: Optional[int] = None
+        self,
+        revisions: List[Sha1Git],
+        ignore_displayname: bool = False,
+        limit: Optional[int] = None,
     ) -> Iterable[Optional[Dict[str, Any]]]:
         """Fetch revision entry from the given root revisions.
 
         Args:
             revisions: array of root revisions to lookup
+            ignore_displayname: return the original author/committer's full name even if
+              it's masked by a displayname.
             limit: limitation on the output result. Default to None.
 
         Yields:
@@ -673,11 +702,15 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("release")
-    def release_get(self, releases: List[Sha1Git]) -> List[Optional[Release]]:
+    def release_get(
+        self, releases: List[Sha1Git], ignore_displayname: bool = False
+    ) -> List[Optional[Release]]:
         """Given a list of sha1, return the releases's information
 
         Args:
             releases: list of sha1s
+            ignore_displayname: return the original author's full name even if it's
+              masked by a displayname.
 
         Returns:
             List of releases matching the identifiers or None if the release does
@@ -769,7 +802,9 @@ class StorageInterface(Protocol):
 
     @remote_api_endpoint("snapshot/count_branches")
     def snapshot_count_branches(
-        self, snapshot_id: Sha1Git, branch_name_exclude_prefix: Optional[bytes] = None,
+        self,
+        snapshot_id: Sha1Git,
+        branch_name_exclude_prefix: Optional[bytes] = None,
     ) -> Optional[Dict[Optional[str], int]]:
         """Count the number of branches in the snapshot with the given id
 
@@ -855,7 +890,8 @@ class StorageInterface(Protocol):
 
     @remote_api_endpoint("origin/visit_status/add")
     def origin_visit_status_add(
-        self, visit_statuses: List[OriginVisitStatus],
+        self,
+        visit_statuses: List[OriginVisitStatus],
     ) -> Dict[str, int]:
         """Add origin visit statuses.
 
@@ -1021,6 +1057,37 @@ class StorageInterface(Protocol):
         """
         ...
 
+    @remote_api_endpoint("origin/visit/get_with_statuses")
+    def origin_visit_get_with_statuses(
+        self,
+        origin: str,
+        allowed_statuses: Optional[List[str]] = None,
+        require_snapshot: bool = False,
+        page_token: Optional[str] = None,
+        order: ListOrder = ListOrder.ASC,
+        limit: int = 10,
+    ) -> PagedResult[OriginVisitWithStatuses]:
+        """Retrieve page of origin visits and all their statuses.
+
+        Origin visit statuses are always sorted in ascending order of their dates.
+
+        Args:
+            origin: The visited origin URL
+            allowed_statuses: Only visit statuses matching that list will be returned.
+                If empty, all visit statuses will be returned. Possible status values
+                are ``created``, ``not_found``, ``ongoing``, ``failed``, ``partial``
+                and ``full``.
+            require_snapshot: If :const:`True`, only visit statuses with a snapshot
+                will be returned.
+            page_token: opaque string used to get the next results
+            order: Order on visit objects to list (default to asc)
+            limit: Number of visits with their statuses to return
+
+        Returns: Page of OriginVisitWithStatuses objects. if next_page_token is
+            None, there is no longer data to retrieve.
+        """
+        ...
+
     @remote_api_endpoint("origin/visit_status/get_random")
     def origin_visit_status_get_random(self, type: str) -> Optional[OriginVisitStatus]:
         """Randomly select one successful origin visit with <type>
@@ -1192,7 +1259,8 @@ class StorageInterface(Protocol):
 
     @remote_api_endpoint("raw_extrinsic_metadata/add")
     def raw_extrinsic_metadata_add(
-        self, metadata: List[RawExtrinsicMetadata],
+        self,
+        metadata: List[RawExtrinsicMetadata],
     ) -> Dict[str, int]:
         """Add extrinsic metadata on objects (contents, directories, ...).
 
@@ -1255,7 +1323,10 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("metadata_fetcher/add")
-    def metadata_fetcher_add(self, fetchers: List[MetadataFetcher],) -> Dict[str, int]:
+    def metadata_fetcher_add(
+        self,
+        fetchers: List[MetadataFetcher],
+    ) -> Dict[str, int]:
         """Add new metadata fetchers to the storage.
 
         Their `name` and `version` together are unique identifiers of this
